@@ -1,21 +1,7 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "connectionsettingtest.h"
@@ -54,25 +40,24 @@ void ConnectionSettingTest::testSetting_data()
     QStringList permissions;
     permissions << "user:foo:bar";
 
-    QTest::newRow("setting1")
-            << QString("test")                                      // id
-            << QString("2815492f-7e56-435e-b2e9-246bd7cdc664")      // uuid
-            << QString("802-3-ethernet")                            // type
-            << permissions                                          // permissions
-            << false                                                // autoconnect
-            << (quint64) 1355945444                                 // timestamp
-            << true                                                 // readOnly
-            << QString("Home")                                      // zone
-            << QString("3ba0ba8c-58f3-427d-bce4-3c8200277a5c")      // master
-            << QString("bond")                                      // slaveType
-            << QStringList{{"2d331115-a2f4-4376-b24e-b8ba6e71abcf"}}// secondaries
-            << (uint)10                                             // gatewayPingTimeout
-            << 10                                                   // autoconnectPriority
-            << 5                                                    // autoconnectRetries
-            << 1                                                    // autoconnectSlaves
-            << 1                                                    // lldp
-            << 1                                                    // metered
-            << QString("${CONNECTION}/${BOOT}");                    // stableId
+    QTest::newRow("setting1") << QString("test") // id
+                              << QString("2815492f-7e56-435e-b2e9-246bd7cdc664") // uuid
+                              << QString("802-3-ethernet") // type
+                              << permissions // permissions
+                              << false // autoconnect
+                              << (quint64)1355945444 // timestamp
+                              << true // readOnly
+                              << QString("Home") // zone
+                              << QString("3ba0ba8c-58f3-427d-bce4-3c8200277a5c") // master
+                              << QString("bond") // slaveType
+                              << QStringList{{"2d331115-a2f4-4376-b24e-b8ba6e71abcf"}} // secondaries
+                              << (uint)10 // gatewayPingTimeout
+                              << 10 // autoconnectPriority
+                              << 5 // autoconnectRetries
+                              << 1 // autoconnectSlaves
+                              << 1 // lldp
+                              << 1 // metered
+                              << QString("${CONNECTION}/${BOOT}"); // stableId
 }
 
 void ConnectionSettingTest::testSetting()
