@@ -1,28 +1,14 @@
 /*
-    Copyright 2013 Lukáš Tinkl <ltinkl@redhat.com>
-    Copyright 2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2014 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include "teamdevice_p.h"
 #include "device_p.h"
 #include "manager.h"
 #include "manager_p.h"
+#include "teamdevice_p.h"
 
 NetworkManager::TeamDevicePrivate::TeamDevicePrivate(const QString &path, TeamDevice *q)
     : DevicePrivate(path, q)
@@ -32,11 +18,6 @@ NetworkManager::TeamDevicePrivate::TeamDevicePrivate(const QString &path, TeamDe
     , iface(NetworkManagerPrivate::DBUS_SERVICE, path, QDBusConnection::systemBus())
 #endif
 {
-    carrier = iface.carrier();
-    hwAddress = iface.hwAddress();
-    Q_FOREACH (const QDBusObjectPath & op, iface.slaves()) {
-        slaves << op.path();
-    }
 }
 
 NetworkManager::TeamDevicePrivate::~TeamDevicePrivate()
@@ -47,7 +28,18 @@ NetworkManager::TeamDevice::TeamDevice(const QString &path, QObject *parent)
     : Device(*new TeamDevicePrivate(path, this), parent)
 {
     Q_D(TeamDevice);
-    connect(&d->iface, &OrgFreedesktopNetworkManagerDeviceTeamInterface::PropertiesChanged, d, &TeamDevicePrivate::propertiesChanged);
+
+    QVariantMap initialProperties = NetworkManagerPrivate::retrieveInitialProperties(d->iface.staticInterfaceName(), path);
+    if (!initialProperties.isEmpty()) {
+        d->propertiesChanged(initialProperties);
+    }
+
+    QDBusConnection::systemBus().connect(NetworkManagerPrivate::DBUS_SERVICE,
+                                         d->uni,
+                                         NetworkManagerPrivate::FDO_DBUS_PROPERTIES,
+                                         QLatin1String("PropertiesChanged"),
+                                         d,
+                                         SLOT(dbusPropertiesChanged(QString, QVariantMap, QStringList)));
 }
 
 NetworkManager::TeamDevice::~TeamDevice()
@@ -79,6 +71,12 @@ QStringList NetworkManager::TeamDevice::slaves() const
     return d->slaves;
 }
 
+QString NetworkManager::TeamDevice::config() const
+{
+    Q_D(const TeamDevice);
+    return d->config;
+}
+
 void NetworkManager::TeamDevicePrivate::propertyChanged(const QString &property, const QVariant &value)
 {
     Q_Q(TeamDevice);
@@ -91,11 +89,15 @@ void NetworkManager::TeamDevicePrivate::propertyChanged(const QString &property,
         Q_EMIT q->hwAddressChanged(hwAddress);
     } else if (property == QLatin1String("Slaves")) {
         QStringList list;
-        Q_FOREACH (const QDBusObjectPath & op, value.value<QList<QDBusObjectPath> >()) {
+        const QList<QDBusObjectPath> opList = qdbus_cast<QList<QDBusObjectPath>>(value);
+        for (const QDBusObjectPath &op : opList) {
             list << op.path();
         }
         slaves = list;
         Q_EMIT q->slavesChanged(slaves);
+    } else if (property == QLatin1String("Config")) {
+        config = value.toString();
+        Q_EMIT q->configChanged(config);
     } else {
         DevicePrivate::propertyChanged(property, value);
     }
